#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://search.cpan.org/~amolloy/Ogg-Vorbis-Header-PurePerl-0.07/PurePerl.pm
# source           : http://search.cpan.org/CPAN/authors/id/A/AM/AMOLLOY/Ogg-Vorbis-Header-PurePerl-0.07.tar.gz

# Source package name
NAME="Ogg-Vorbis-Header-PurePerl"
# Zenwalk package name
ZENNAME="perl_Ogg-Vorbis-Header-PurePerl"
# Perl package name
PERLNAME="Ogg::Vorbis::Header::PurePerl"
# Package version
VERSION="0.07"
# Source code URL
SOURCE="http://search.cpan.org/CPAN/authors/id/A/AM/AMOLLOY/Ogg-Vorbis-Header-PurePerl-$VERSION.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="Changes LICENSE.GPL MANIFEST README"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="noarch"
BUILD="54.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$ZENNAME: Ogg-Vorbis-Header-PurePerl - An interface to Ogg Vorbis comments
$ZENNAME:
$ZENNAME: Ogg::Vorbis::Header::PurePerl - An object-oriented interface to
$ZENNAME: Ogg Vorbis information and comment fields, implemented entirely
$ZENNAME: in Perl. Intended to be a drop in replacement for
$ZENNAME: Ogg::Vobis::Header.
$ZENNAME:
$ZENNAME: Unlike Ogg::Vorbis::Header, this module will go ahead and fill
$ZENNAME: in all of the information fields as soon as you construct the
$ZENNAME: object. In other words, the new and load constructors have
$ZENNAME: identical behavior.
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

# make
cd $NAME-$VERSION
perl Makefile.PL
# Patch for proper mandir
sed -i -e 's,share/,,' Makefile
# Now do make
make

# Install on temporary directory
make install DESTDIR=$PKG

# Take care of the perllocal.pod file which also exists in other packages
mv $PKG/usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod $PKG/usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod.$NAME

# Create the doinst.sh script for the perllocal.pod file
cat > $PKG/install/doinst.sh << EOF
configcat() {
  NEW="usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod.\$1"
  OLD="usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod"
  # If there's no file by that name, mv it over:
  if [ ! -r "\$OLD" ]; then
    mv "\$NEW" "\$OLD"
  elif grep "$PERLNAME|" "\$OLD" &> /dev/null ; then # don't append it twice
    rm "\$NEW" &>/dev/null
  else
    cat "\$NEW" >> "\$OLD"
    rm "\$NEW"
  fi
}
configcat $NAME
EOF

# Copy Docs
mkdir -p $PKG/usr/doc/$ZENNAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$ZENNAME-$VERSION

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$ZENNAME-$VERSION
cp "$CWD/build-$ZENNAME.sh" "$PKG/usr/src/$ZENNAME-$VERSION/build-$ZENNAME.sh"
chmod a+x "$PKG/usr/src/$ZENNAME-$VERSION/build-$ZENNAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$ZENNAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $ZENNAME-$VERSION-$ARCH-$BUILD.tgz > $ZENNAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG

cat > $ZENNAME-$VERSION-$ARCH-$BUILD.src << EOF
http://pnboy.pinguix.com/gapan/$ZENNAME/build-$ZENNAME.sh
http://search.cpan.org/CPAN/authors/id/A/AM/AMOLLOY/Ogg-Vorbis-Header-PurePerl-$VERSION.tar.gz
EOF
